from hungovercoders_template_python_package import hello

hello("griff")